hyperspy.tests.signal package
=============================

Submodules
----------

hyperspy.tests.signal.test_1D_tools module
------------------------------------------

.. automodule:: hyperspy.tests.signal.test_1D_tools
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_2D_tools module
------------------------------------------

.. automodule:: hyperspy.tests.signal.test_2D_tools
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_apply_function module
------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_apply_function
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_assign_subclass module
-------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_assign_subclass
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_attributes module
--------------------------------------------

.. automodule:: hyperspy.tests.signal.test_attributes
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_binned module
----------------------------------------

.. automodule:: hyperspy.tests.signal.test_binned
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_eds_sem module
-----------------------------------------

.. automodule:: hyperspy.tests.signal.test_eds_sem
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_eds_tem module
-----------------------------------------

.. automodule:: hyperspy.tests.signal.test_eds_tem
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_eels module
--------------------------------------

.. automodule:: hyperspy.tests.signal.test_eels
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_fancy_indexing module
------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_fancy_indexing
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_find_peaks1D_ohaver module
-----------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_find_peaks1D_ohaver
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_folding module
-----------------------------------------

.. automodule:: hyperspy.tests.signal.test_folding
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_image module
---------------------------------------

.. automodule:: hyperspy.tests.signal.test_image
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_integrate_in_range module
----------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_integrate_in_range
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_kramers_kronig_transform module
----------------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_kramers_kronig_transform
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_remove_background module
---------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_remove_background
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_rgb module
-------------------------------------

.. automodule:: hyperspy.tests.signal.test_rgb
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_signal_operators module
--------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_signal_operators
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_signal_subclass_conversion module
------------------------------------------------------------

.. automodule:: hyperspy.tests.signal.test_signal_subclass_conversion
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_spectrum module
------------------------------------------

.. automodule:: hyperspy.tests.signal.test_spectrum
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy.tests.signal.test_tools module
---------------------------------------

.. automodule:: hyperspy.tests.signal.test_tools
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.signal
    :members:
    :undoc-members:
    :show-inheritance:
